@@ -55,10 +55,10 @@ class TQ_EXPORT TQt3CairoPaintDevice : public TQPaintDevice		// picture class
 		void transferIntermediateSurface();
 		bool intermediateSurfaceInUse() const;
 
-		void updatePen(bool backgroundStroke=FALSE);
+		void updatePen(bool backgroundStroke=false);
 		void dualStrokePen();
 
-		void updateBrush(bool backgroundStroke=FALSE, cairo_fill_rule_t fillMethod=CAIRO_FILL_RULE_WINDING);
+		void updateBrush(bool backgroundStroke=false, cairo_fill_rule_t fillMethod=CAIRO_FILL_RULE_WINDING);
 		void dualStrokeBrush(cairo_fill_rule_t fillMethod=CAIRO_FILL_RULE_WINDING);
 
 		void drawPolygon(const TQPointArray* pointarray, bool winding, bool fill, bool close);
